@@ -1,3 +1,12 @@
+#
+# This file is part of CPAN-Reporter
+#
+# This software is Copyright (c) 2006 by David Golden.
+#
+# This is free software, licensed under:
+#
+#   The Apache License, Version 2.0, January 2004
+#
 package t::Helper;
 use strict;
 BEGIN{ if (not $] < 5.006) { require warnings; warnings->import } }
@@ -12,18 +21,20 @@ use vars qw/@EXPORT/;
     test_dispatch test_dispatch_plan
 /;
 
-use base 'Exporter';
+use Exporter ();
+our @ISA = 'Exporter';
 
 use Config;
+use Archive::Tar 1.54 ();
 use File::Basename qw/basename/;
-use File::Copy::Recursive qw/dircopy/;
+use File::Copy::Recursive 0.35 qw/dircopy/;
 use File::Path qw/mkpath/;
-use File::pushd qw/tempd/;
-use File::Spec ();
-use File::Temp qw/tempdir/;
-use IO::CaptureOutput qw/capture/;
+use File::pushd 0.32 qw/pushd tempd/;
+use File::Spec 3.19 ();
+use File::Temp 0.16 qw/tempdir/;
+use IO::CaptureOutput 1.03 qw/capture/;
 use Probe::Perl ();
-use Test::More;
+use Test::More 0.62;
 
 use t::MockHomeDir;
 
@@ -34,9 +45,17 @@ use t::MockHomeDir;
 my $perl = Probe::Perl->find_perl_interpreter();
 my $make = $Config{make};
 
-my $temp_stdout = File::Temp->new() 
+my $temp_stdout = File::Temp->new()
     or die "Couldn't make temporary file:$!\nIs your temp drive full?";
 
+my $temp_dist_dir = tempdir( 'CR-t-dist-XXXXXX', CLEANUP => 1, TMPDIR => 1);
+my $dist_archive = File::Spec->rel2abs("t/dist.tgz");
+{
+  my $wd = pushd($temp_dist_dir);
+  Archive::Tar->extract_archive($dist_archive, 1)
+    or die "Could not extract test distributions: " . Archive::Tar->error;
+}
+
 my $home_dir = t::MockHomeDir::home_dir();
 my $config_dir = File::Spec->catdir( $home_dir, ".cpanreporter" );
 my $config_file = File::Spec->catfile( $config_dir, "config.ini" );
@@ -58,7 +77,7 @@ my %tool_constants = (
     },
 );
 
-my $max_report_length = 50_000; # 50K
+my $max_report_length = 1_000_000; # 1000K
 
 # used to capture from fixtures
 use vars qw/$sent_report @cc_list/;
@@ -74,7 +93,7 @@ sub test_fake_config {
 
     is( File::HomeDir::my_documents(), t::MockHomeDir::home_dir(),
         "home directory mocked"
-    ); 
+    );
     mkpath $config_dir;
     ok( -d $config_dir,
         "config directory created"
@@ -84,7 +103,6 @@ sub test_fake_config {
     $tiny->{_}{email_from} = $bogus_email_from;
     $tiny->{_}{email_to} = $bogus_email_to; # failsafe
     $tiny->{_}{smtp_server} = $bogus_smtp;
-    $tiny->{_}{cc_author} = "yes";
     $tiny->{_}{send_report} = "yes";
     $tiny->{_}{send_duplicates} = "yes"; # tests often repeat same stuff
     for my $key ( keys %overrides ) {
@@ -100,7 +118,7 @@ sub test_fake_config {
 #--------------------------------------------------------------------------#
 
 sub test_grade_PL_iter_plan() { 5 }
-sub test_grade_PL_plan() { test_grade_PL_iter_plan() * 2 } 
+sub test_grade_PL_plan() { test_grade_PL_iter_plan() * 2 }
 sub test_grade_PL {
     my ($case, $dist) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
@@ -109,28 +127,27 @@ sub test_grade_PL {
 
     for my $tool ( qw/eumm mb/ ) {
         SKIP: {
-            my ($have_tool,$tool_mod,$tool_PL) = 
+            my ($have_tool,$tool_mod,$tool_PL) =
                 @{$tool_constants{$tool}}{qw/have module PL/};
-            my $tool_label = $tool eq 'eumm'  ? "Makefile.PL" 
+            my $tool_label = $tool eq 'eumm'  ? "Makefile.PL"
                                             : "Build.PL";
-            my $tool_cmd = "$perl $tool_label"; 
+            my $tool_cmd = "$perl $tool_label";
 
             skip "$tool_mod not installed or working", test_grade_PL_iter_plan()
                 if ! $have_tool;
-            
+
             my $tempd = _ok_clone_dist_dir( $case->{name} );
             local $dist->{build_dir} = "$tempd";
-            
+
             $t::Helper::sent_report = undef;
             $t::Helper::comments = undef;
-            @t::Helper::cc_list = ();
 
-            my ($stdout, $stderr, $build_rc, $test_build_rc, 
+            my ($stdout, $stderr, $build_rc, $test_build_rc,
                 $output, $exit_value, $rc);
 
             eval {
                 capture sub {
-                    ($output, $exit_value) = 
+                    ($output, $exit_value) =
                         CPAN::Reporter::record_command($tool_cmd);
                     $rc = CPAN::Reporter::grade_PL(
                         $dist, $tool_cmd, $output, $exit_value
@@ -142,27 +159,27 @@ sub test_grade_PL {
                 _diag_output( $stdout, $stderr );
                 skip "died grading PL", test_grade_PL_iter_plan() - 1;
             }
-            
-            my $is_rc_correct = $case->{"$tool\_success"} 
+
+            my $is_rc_correct = $case->{"$tool\_success"}
                               ? $rc : ! $rc;
 
-            ok( $is_rc_correct, 
-                "$case->{name}: grade_PL() for $tool_PL returned " . 
+            ok( $is_rc_correct,
+                "$case->{name}: grade_PL() for $tool_PL returned " .
                 $case->{"$tool\_success"}
             );
-            
+
             my $case_grade = $case->{"$tool\_grade"};
             my $is_grade_correct;
 
             # Grade evaluation with special case if discarding
-            my ($found_grade_result, $found_msg) = 
+            my ($found_grade_result, $found_msg) =
                 ( $stdout =~ /^CPAN::Reporter: ([^,]+), ([^\n]+)/ms );
             if ( $case_grade eq 'discard' ) {
                 is ($found_grade_result, "test results were not valid",
                     "$case->{name}: '$tool_label' saw test results not valid message"
                 );
-                    
-                like( $stdout, 
+
+                like( $stdout,
                     "/Test report will not be sent/",
                     "$case->{name}: discard message correct"
                 ) and $is_grade_correct++;
@@ -173,12 +190,12 @@ sub test_grade_PL {
             }
             else {
                 my ($found_grade) = ( $found_grade_result =~ /$tool_label result is '([^']+)'/ );
-                is( $found_grade, $case_grade, 
+                is( $found_grade, $case_grade,
                     "$case->{name}: '$tool_label' grade reported as '$case_grade'"
                 ) or _diag_output( $stdout, $stderr );
-                
+
                 my $ctr_regex = "/preparing a CPAN Testers report for \Q$short_name\E/";
-                
+
                 if ( $case_grade eq 'pass' ) {
                     unlike( $stdout, $ctr_regex ,
                         "$case->{name}: report notification correct"
@@ -204,7 +221,7 @@ sub test_grade_PL {
                 }
             }
 
-            _diag_output( $stdout, $stderr ) 
+            _diag_output( $stdout, $stderr )
                 unless ( $is_rc_correct && $is_grade_correct );
         } # SKIP
     } # for
@@ -215,7 +232,7 @@ sub test_grade_PL {
 #--------------------------------------------------------------------------#
 
 sub test_grade_make_iter_plan() { 6 }
-sub test_grade_make_plan() { test_grade_make_iter_plan() * 2 } 
+sub test_grade_make_plan() { test_grade_make_iter_plan() * 2 }
 sub test_grade_make {
     my ($case, $dist) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
@@ -224,22 +241,21 @@ sub test_grade_make {
 
     for my $tool ( qw/eumm mb/ ) {
         SKIP: {
-            my ($have_tool,$tool_mod,$tool_PL) = 
+            my ($have_tool,$tool_mod,$tool_PL) =
                 @{$tool_constants{$tool}}{qw/have module PL/};
             my $tool_cmd = $tool eq 'eumm' ? $Config{make} : "$perl Build";
             my $tool_label = $tool eq 'eumm' ? $Config{make} : "Build";
 
             skip "$tool_mod not installed or working", test_grade_make_iter_plan()
                 if ! $have_tool;
-            
+
             # Set up temporary directory for the case
             my $tempd = _ok_clone_dist_dir( $case->{name} );
 
             $t::Helper::sent_report = undef;
             $t::Helper::comments = undef;
-            @t::Helper::cc_list = ();
 
-            my ($stdout, $stderr, $build_err, $test_build_rc, 
+            my ($stdout, $stderr, $build_err, $test_build_rc,
                 $output, $exit_value, $rc);
 
             capture sub {
@@ -253,7 +269,7 @@ sub test_grade_make {
                 };
             eval {
                 capture sub {
-                    ($output, $exit_value) = 
+                    ($output, $exit_value) =
                     CPAN::Reporter::record_command($tool_cmd);
                     $rc = CPAN::Reporter::grade_make(
                         $dist, $tool_cmd, $output, $exit_value
@@ -266,11 +282,11 @@ sub test_grade_make {
                 skip "died grading make", test_grade_make_iter_plan() - 1;
             }
 
-            my $is_rc_correct = $case->{"$tool\_success"} 
+            my $is_rc_correct = $case->{"$tool\_success"}
             ? $rc : ! $rc;
 
-            ok( $is_rc_correct, 
-                "$case->{name}: grade_make() for $tool_label returned " . 
+            ok( $is_rc_correct,
+                "$case->{name}: grade_make() for $tool_label returned " .
                 $case->{"$tool\_success"}
             );
 
@@ -278,14 +294,14 @@ sub test_grade_make {
             my $is_grade_correct;
 
             # Grade evaluation with special case if discarding
-            my ($found_grade_result, $found_msg) = 
+            my ($found_grade_result, $found_msg) =
                 ( $stdout =~ /^CPAN::Reporter: ([^,]+), ([^\n]+)/ms );
             if ( $case_grade eq 'discard' ) {
                 is ($found_grade_result, "test results were not valid",
                     "$case->{name}: '$tool_label' prerequisites not satisifed"
                 );
-                    
-                like( $stdout, 
+
+                like( $stdout,
                     "/Test report will not be sent/",
                     "$case->{name}: discard message correct"
                 ) and $is_grade_correct++;
@@ -296,12 +312,12 @@ sub test_grade_make {
             }
             else {
                 my ($found_grade) = ( $found_grade_result =~ /$tool_label result is '([^']+)'/ );
-                is( $found_grade, $case_grade, 
+                is( $found_grade, $case_grade,
                     "$case->{name}: '$tool_label' grade reported as '$case_grade'"
                 ) or _diag_output( $stdout, $stderr );
-                
+
                 my $ctr_regex = "/preparing a CPAN Testers report for \Q$short_name\E/";
-                
+
                 if ( $case_grade eq 'pass' ) {
                     unlike( $stdout, $ctr_regex ,
                         "$case->{name}: report notification correct"
@@ -331,7 +347,7 @@ sub test_grade_make {
                 unless ( $is_rc_correct && $is_grade_correct );
 
         } #SKIP
-    } #for   
+    } #for
 }
 
 #--------------------------------------------------------------------------#
@@ -348,7 +364,7 @@ sub test_grade_test {
 
     for my $tool ( qw/eumm mb/ ) {
         SKIP: {
-            my ($have_tool,$tool_mod,$tool_PL) = 
+            my ($have_tool,$tool_mod,$tool_PL) =
                 @{$tool_constants{$tool}}{qw/have module PL/};
             my $tool_cmd = $tool eq 'eumm'  ?  "$make test"
                                             :  "$perl Build test" ;
@@ -356,13 +372,12 @@ sub test_grade_test {
                                             :  "perl Build test" ;
 
             skip "$tool_mod not installed or working", test_grade_test_iter_plan()
-                if ! $have_tool; 
+                if ! $have_tool;
 
             my $tempd = _ok_clone_dist_dir( $case->{name} );
-                
+
             $t::Helper::sent_report = undef;
             $t::Helper::comments = undef;
-            @t::Helper::cc_list = ();
 
             my ($stdout, $stderr, $build_err, $test_build_rc);
 
@@ -387,22 +402,22 @@ sub test_grade_test {
                 skip "test() died", test_grade_test_iter_plan() - 1;
             }
 
-            my $is_rc_correct = $case->{"$tool\_success"} 
+            my $is_rc_correct = $case->{"$tool\_success"}
                               ? $test_build_rc : ! $test_build_rc;
-            ok( $is_rc_correct, 
-                "$case->{name}: '$tool_label' returned " . 
+            ok( $is_rc_correct,
+                "$case->{name}: '$tool_label' returned " .
                 $case->{"$tool\_success"}
             );
-            
+
             # Grade evaluation with special case if discarding
-            my ($found_grade_result, $found_msg) = 
-                ( $stdout =~ /^CPAN::Reporter: (Test result[^,]+), ([^\n]+)$/ims );
+            my ($found_grade_result, $found_msg) =
+                ( $stdout =~ /^CPAN::Reporter: (Test result[^,]+), ([^\n]+)[.:]$/ims );
             if ( $case->{"$tool\_grade"} eq 'discard' ) {
                 is ($found_grade_result, "test results were not valid",
                     "$case->{name}: '$tool_label' prerequisites not satisifed"
                 );
-                    
-                like( $stdout, 
+
+                like( $stdout,
                     "/Test report will not be sent/",
                     "$case->{name}: discard message correct"
                 );
@@ -414,10 +429,10 @@ sub test_grade_test {
             else {
                 my $case_grade = $case->{"$tool\_grade"};
                 my ($found_grade) = ( $found_grade_result =~ /Test result is '([^']+)'/ );
-                is( $found_grade, $case_grade, 
+                is( $found_grade, $case_grade,
                     "$case->{name}: '$tool_label' grade reported as '$case_grade'"
                 ) or _diag_output( $stdout, $stderr );
-                
+
                 like( $stdout, "/preparing a CPAN Testers report for \Q$short_name\E/",
                     "$case->{name}: report notification correct"
                 );
@@ -433,10 +448,10 @@ sub test_grade_test {
                     );
                 }
             }
-            
+
             # Grade explanation message
-            is( $found_msg, 
-                $case->{"$tool\_msg"} ? $case->{"$tool\_msg"} . q{.} : q{},
+            is( $found_msg,
+                $case->{"$tool\_msg"} ? $case->{"$tool\_msg"} : q{},
                 "$case->{name}: '$tool_label' grade explanation correct"
             );
 
@@ -462,34 +477,34 @@ If you think this report is invalid, please consult the CPAN Testers Wiki
 for suggestions on how to avoid getting FAIL reports for missing library
 or binary dependencies, unsupported operating systems, and so on:
 
-http://cpantest.grango.org/wiki/CPANAuthorNotes
+http://wiki.cpantesters.org/wiki/CPANAuthorNotes
 HERE
 
     'unknown' => << 'HERE',
 Thank you for uploading your work to CPAN.  However, attempting to
-test your distribution gave an inconclusive result.  
+test your distribution gave an inconclusive result.
 
-This could be because you did not define tests, tests could not be 
-found, because your tests were interrupted before they finished, or 
-because the results of the tests could not be parsed.  You may wish to 
-consult the CPAN Testers Wiki:
+This could be because your distribution had an error during the make/build
+stage, did not define tests, tests could not be found, because your tests were
+interrupted before they finished, or because the results of the tests could not
+be parsed.  You may wish to consult the CPAN Testers Wiki:
 
-http://cpantest.grango.org/wiki/CPANAuthorNotes
+http://wiki.cpantesters.org/wiki/CPANAuthorNotes
 HERE
 
     'na' => << 'HERE',
-Thank you for uploading your work to CPAN.  While attempting to build or test 
-this distribution, the distribution signaled that support is not available 
-either for this operating system or this version of Perl.  Nevertheless, any 
-diagnostic output produced is provided below for reference.  If this is not 
+Thank you for uploading your work to CPAN.  While attempting to build or test
+this distribution, the distribution signaled that support is not available
+either for this operating system or this version of Perl.  Nevertheless, any
+diagnostic output produced is provided below for reference.  If this is not
 what you expect, you may wish to consult the CPAN Testers Wiki:
 
-http://cpantest.grango.org/wiki/CPANAuthorNotes
+http://wiki.cpantesters.org/wiki/CPANAuthorNotes
 HERE
-    
+
 );
 
-sub test_report_plan() { 14 };
+sub test_report_plan() { 13 };
 sub test_report {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
@@ -503,23 +518,23 @@ sub test_report {
         : "none provided" ;
 
     my $tempd = _ok_clone_dist_dir( $case->{name} );
-                
+
     my ($stdout, $stderr, $err, $test_output) = _run_report( $case );
-    
-    is( $err, q{}, 
-        "$label report ran without error" 
+
+    is( $err, q{},
+        "$label report ran without error"
     );
 
     ok( defined $msg_re && length $msg_re,
         "$label found '$expected_grade' grade paragraph"
     );
-    
+
     # set PERL_MM_USE_DEFAULT to mirror _run_report
     local $ENV{PERL_MM_USE_DEFAULT} = 1;
     my $env_vars = CPAN::Reporter::_env_report();
     my $special_vars = CPAN::Reporter::_special_vars_report();
     my $toolchain_versions = CPAN::Reporter::_toolchain_report();
-    
+
     like( $t::Helper::sent_report, '/' . quotemeta($msg_re) . '/ms',
         "$label correct intro paragraph"
     );
@@ -531,19 +546,19 @@ sub test_report {
     like( $t::Helper::sent_report, '/' . quotemeta($prereq) . '/ms',
         "$label found prereq report"
     );
-    
+
     like( $t::Helper::sent_report, '/' . quotemeta($env_vars) . '/ms',
         "$label found environment variables"
     );
-    
+
     like( $t::Helper::sent_report, '/' . quotemeta($special_vars) . '/ms',
         "$label found special variables"
     );
-    
+
     like( $t::Helper::sent_report, '/' . quotemeta($toolchain_versions) . '/ms',
         "$label found toolchain versions found"
     );
-    
+
     my $joined_output = join("", @$test_output);
 
     # extract just the test output
@@ -554,14 +569,14 @@ sub test_report {
         ^(.+) \n                            # test output ending in newline
         ^------------------------------ \n  # separator
         ^PREREQUISITES \n                   # next section
-        /xms ) 
+        /xms )
     {
         $found_test_output = $1;
     }
-    
+
     my $orig_found_length = length $found_test_output;
     ok( $orig_found_length, "$label located test output in report" );
-    
+
     # if output appears longer than max, the excess should only be the
     # error message, so look for it, strip it and check it
     my $length_error = q{};
@@ -590,7 +605,7 @@ sub test_report {
     # after extracting error, if any, the output should now be
     # less than the max length
     my $found_length = length $found_test_output;
-    ok( $found_length <= $max_report_length, 
+    ok( $found_length <= $max_report_length,
         "$label test_output less than or equal to maximum length"
     ) or diag "length $found_length > $max_report_length";
 
@@ -604,15 +619,6 @@ sub test_report {
         "$label found output matches expected output"
     );
 
-    my @expected_cc;
-    my $author = $case->{dist}->author;
-    push @expected_cc, $author->id if defined $author && !$Config{perl_patchlevel};
-    is_deeply( 
-        [ @t::Helper::cc_list ], 
-        [ map { $_ . '@cpan.org' } @expected_cc ],
-        "$label cc list correct"
-    );
-
     return ($stdout, $stderr, $err, $test_output);
 };
 
@@ -635,11 +641,11 @@ sub test_dispatch {
 
     my $tempd = _ok_clone_dist_dir( $case->{name} );
     local $case->{dist}{build_dir} = "$tempd";
-                
+
     my ($stdout, $stderr, $err) = _run_report( $case );
 
-    is( $err, q{}, 
-            "generate report for $case->{label}" 
+    is( $err, q{},
+            "generate report for $case->{label}"
     );
 
     if ( $opt{will_send} ) {
@@ -668,7 +674,7 @@ sub test_dispatch {
 
 sub _diag_output {
     my ( $stdout, $stderr ) = @_;
-    diag "STDOUT:\n$stdout\n\nSTDERR:\n$stderr\n"; 
+    diag "STDOUT:\n$stdout\n\nSTDERR:\n$stderr\n";
 }
 
 #--------------------------------------------------------------------------#
@@ -678,10 +684,8 @@ sub _diag_output {
 sub _ok_clone_dist_dir {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
     my $dist_name = shift;
-    my $dist_dir = File::Spec->rel2abs(
-        File::Spec->catdir( qw/t dist /, $dist_name )
-    );
-    my $work_dir = tempd() 
+    my $dist_dir = File::Spec->catdir( $temp_dist_dir, "dist", $dist_name );
+    my $work_dir = tempd()
         or die "Couldn't create temporary distribution dir: $!\n";
 
     # workaround badly broken F::C::R 0.34 on Windows
@@ -709,12 +713,11 @@ sub _run_report {
 
     # automate CPAN::Reporter prompting
     local $ENV{PERL_MM_USE_DEFAULT} = 1;
-    
+
     my ($stdout, $stderr, $output, $exit_value);
-    
+
     $t::Helper::sent_report = undef;
     $t::Helper::comments = undef;
-    @t::Helper::cc_list = ();
 
     eval {
         capture sub {
@@ -725,7 +728,7 @@ sub _run_report {
             if ( $phase eq 'test' ) {
                 system("$make");
             }
-            ($output, $exit_value) = 
+            ($output, $exit_value) =
                 CPAN::Reporter::record_command( $case->{command} );
             no strict 'refs';
             &{"CPAN::Reporter::grade_$phase"}(
@@ -735,7 +738,7 @@ sub _run_report {
                 $exit_value,
             );
         } => \$stdout, \$stderr;
-    }; 
+    };
     if ( $@ ) {
         diag "DIED WITH:\n$@";
         _diag_output( $stdout, $stderr );
@@ -764,7 +767,8 @@ BEGIN {
 }
 
 package Test::Reporter;
-use vars qw/$AUTOLOAD/;
+use vars qw/$AUTOLOAD $VERSION/;
+$VERSION = 999; # more than 1.54 (e.g. distfile exists)
 
 sub new { return bless {}, 'Test::Reporter::Mocked' }
 
@@ -774,12 +778,11 @@ use vars qw/$AUTOLOAD/;
 
 sub comments { shift; $t::Helper::comments = shift }
 
-sub send { 
-    shift; 
-    $t::Helper::sent_report = $t::Helper::comments; 
-    @t::Helper::cc_list = ( @_ ); 
-    return 1 
-} 
+sub send {
+    shift;
+    $t::Helper::sent_report = $t::Helper::comments;
+    return 1
+}
 
 sub subject {
     my $self = shift;
@@ -801,7 +804,7 @@ sub transport {
     }
     return $mocked_data{transport};
 }
-    
+
 sub AUTOLOAD {
     my $self = shift;
     if ( @_ ) {
